@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QCompleter>
 #include <QIcon>
 #include <QLineEdit>
+#include <QLabel>
 #include <QPainter>
 #include <QPainterPath>
 #include <QTimer>
@@ -220,6 +221,62 @@ void TagFilterWidget::updateTagSetFilter()
 }
 #endif
 
+ImageDimensionsWidget::ImageDimensionsWidget(SortedDirModel *model)
+{
+    mFilter = new ImageDimensions(model);
+
+    mModeComboBox = new KComboBox;
+    mModeComboBox->addItem(i18n("Dimensions >="), ImageDimensions::GreaterOrEqual);
+    mModeComboBox->addItem(i18n("Dimensions ="), ImageDimensions::Equal);
+    mModeComboBox->addItem(i18n("Dimensions <="), ImageDimensions::LessOrEqual);
+
+
+    mLineEditHeight = new  QLineEdit;
+    mLineEditHeight->setValidator( new QIntValidator(ImageDimensions::minImageSizePx, ImageDimensions::maxImageSizePx, this) );
+    mLineEditWidth =  new QLineEdit;
+    mLineEditWidth->setValidator( new QIntValidator(ImageDimensions::minImageSizePx, ImageDimensions::maxImageSizePx, this) );
+    mLabelHeight = new QLabel;
+    mLabelHeight->setText(i18n("Height"));
+    mLabelWidth = new QLabel;
+    mLabelWidth->setText(i18n("Width"));
+
+
+
+    auto *layout = new QHBoxLayout(this);
+    layout->setContentsMargins(0, 0, 0, 0);
+    layout->addWidget(mModeComboBox);
+    layout->addWidget(mLabelWidth);
+    layout->addWidget(mLineEditWidth);
+    layout->addWidget(mLabelHeight);
+    layout->addWidget(mLineEditHeight);
+
+
+
+    connect(mModeComboBox, SIGNAL(currentIndexChanged(int)), SLOT(applyImageDimensions()));
+    connect(mLineEditHeight, &QLineEdit::editingFinished, this,  &ImageDimensionsWidget::applyImageDimensions);
+    connect(mLineEditWidth, &QLineEdit::editingFinished, this,  &ImageDimensionsWidget::applyImageDimensions);
+
+    applyImageDimensions();
+}
+
+ImageDimensionsWidget::~ImageDimensionsWidget()
+{
+    delete mFilter;
+}
+
+void ImageDimensionsWidget::applyImageDimensions()
+{
+    QVariant data = mModeComboBox->itemData(mModeComboBox->currentIndex());
+    uint32_t width = 0;
+    uint32_t height = 0;
+
+    width = mLineEditWidth->text().toUInt();
+    height = mLineEditHeight->text().toUInt();
+
+    mFilter->setMode(ImageDimensions::Mode(data.toInt()));
+    mFilter->setSizes(width, height);
+}
+
 /**
  * A container for all filter widgets. It features a close button on the right.
  */
@@ -284,6 +341,7 @@ FilterController::FilterController(QFrame *frame, SortedDirModel *dirModel)
 
     addAction(i18nc("@action:inmenu", "Filter by Tag"), SLOT(addFilterByTag()), QKeySequence());
 #endif
+    addAction(i18nc("@action:inmenu", "Filter by Dimensions"), SLOT(addFilterByImageDimensions()), QKeySequence());
 }
 
 QList<QAction *> FilterController::actionList() const
@@ -313,6 +371,11 @@ void FilterController::addFilterByTag()
 }
 #endif
 
+void FilterController::addFilterByImageDimensions()
+{
+    addFilter(new ImageDimensionsWidget(mDirModel));
+}
+
 void FilterController::slotFilterWidgetClosed()
 {
     mFilterWidgetCount--;
